#
# spec file for package enchant
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%bcond_without nuspell
%else
%bcond_with nuspell
%endif
%bcond_without aspell

Name:           enchant
Version:        2.2.15
Release:        3.6
Summary:        Generic Spell Checking Library
License:        LGPL-2.1-or-later
URL:            https://abiword.github.io/enchant/
Source:         https://github.com/AbiWord/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
%if %{with aspell}
BuildRequires:  aspell-devel
%endif
BuildRequires:  dbus-1-glib-devel
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  hunspell-devel
BuildRequires:  libvoikko-devel
%if %{with nuspell}
BuildRequires:  libboost_headers-devel
BuildRequires:  nuspell-devel >= 4.1.0
%endif

%description
A library providing an efficient extensible abstraction for dealing
with different spell checking libraries.

%package tools
Summary:        Command line tools for the Enchant spell checking library

%description tools
A library providing an efficient extensible abstraction for dealing
with different spell checking libraries.

This package provides command-line tools to interact with enchant.

%package data
Summary:        Data files for libenchant
# enchant up to version 1.6.1 was not packaged properly according the SLPP
Conflicts:      libenchant1 < 1.6.1

%description data
A library providing an efficient extensible abstraction for dealing
with different spell checking libraries.

This package provides data/configuration files for libenchant.

%if %{with aspell}
%package -n enchant-2-backend-aspell
Summary:        Aspell backend for the Enchant spell checking library
Supplements:    packageand(libenchant-2-2:%(rpm -q --qf "%%{name}" -f $(readlink -f %{_libdir}/libaspell.so)))
Provides:       enchant-2-backend

%description -n enchant-2-backend-aspell
Aspell plugin for enchant, a library providing an efficient
extensible abstraction for dealing with different spell checking
libraries.
%endif

%package -n enchant-2-backend-hunspell
Summary:        Hunspell backend for the Enchant spell checking library
Supplements:    packageand(libenchant-2-2:%(rpm -q --qf "%%{name}" -f $(readlink -f %{_libdir}/libhunspell.so)))
Provides:       enchant-2-backend

%description -n enchant-2-backend-hunspell
Hunspell plugin for enchant, a library providing an efficient
extensible abstraction for dealing with different spell checking
libraries.

%package -n enchant-2-backend-nuspell
Summary:        Nuspell backend for the Enchant spell checking library
Supplements:    packageand(libenchant-2-2:%(rpm -q --qf "%%{name}" -f $(readlink -f %{_libdir}/libnuspell.so)))
Provides:       enchant-2-backend

%description -n enchant-2-backend-nuspell
Nuspell plugin for enchant, a library providing an efficient
extensible abstraction for dealing with different spell checking
libraries.

%package -n enchant-2-backend-voikko
Summary:        Voikko backend for the Enchant spell checking library
Supplements:    packageand(libenchant-2-2:%(rpm -q --qf "%%{name}" -f $(readlink -f %{_libdir}/libvoikko.so)))
Provides:       enchant-2-backend
Provides:       locale(libenchant-2-2:fi)

%description -n enchant-2-backend-voikko
Voikko plugin (Finnish) for enchant, a library providing an efficient
extensible abstraction for dealing with different spell checking
libraries.

%package -n libenchant-2-2
Summary:        Generic Spell Checking Library
Requires:       enchant-2-backend
Requires:       enchant-data >= %{version}
Suggests:       enchant-2-backend-hunspell

%description -n libenchant-2-2
A library providing an efficient extensible abstraction for dealing
with different spell checking libraries.

%package devel
Summary:        Development files for the Enchant spell checking library
Requires:       glib2-devel
Requires:       libenchant-2-2 = %{version}
Requires:       libstdc++-devel

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%setup -q

%build
%configure \
%if %{with aspell}
    --with-aspell \
%endif
    --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libenchant-2-2 -p /sbin/ldconfig
%postun -n libenchant-2-2 -p /sbin/ldconfig

%files tools
%{_bindir}/enchant-2
%{_bindir}/enchant-lsmod-2
%{_mandir}/man1/enchant-2.1%{?ext_man}
%{_mandir}/man1/enchant-lsmod-2.1%{?ext_man}

%files -n libenchant-2-2
%license COPYING.LIB
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/*.so.*
%dir %{_libdir}/enchant-2

%if %{with aspell}
%files -n enchant-2-backend-aspell
%dir %{_libdir}/enchant-2
%{_libdir}/enchant-2/enchant_aspell.so
%endif

%files -n enchant-2-backend-hunspell
%dir %{_libdir}/enchant-2
%{_libdir}/enchant-2/enchant_hunspell.so

%if %{with nuspell}
%files -n enchant-2-backend-nuspell
%dir %{_libdir}/enchant-2
%{_libdir}/enchant-2/enchant_nuspell.so
%endif

%files -n enchant-2-backend-voikko
%dir %{_libdir}/enchant-2
%{_libdir}/enchant-2/enchant_voikko.so

%files data
# The directories are not versioned, unfortunately. Not good for the SLPP.
%dir %{_datadir}/enchant
%{_datadir}/enchant/enchant.ordering

%files devel
%{_includedir}/enchant-2
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Feb 24 2023 pgajdos@suse.com
- Use %%bcond_without aspell, ref ALP push for as few mandatory
  dependencies as possible/ability to turn off dependencies.
* Fri Jan  7 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add missing closing parentheses for packageand Supplements.
* Tue Mar 16 2021 Dirk Müller <dmueller@suse.com>
- Update to version 2.2.15:
  + Specify that nuspell >= 4.1.0 is required.
  + Fix some space leaks in the tests.
  + The nuspell backend is updated for newer versions.
  + Make the enchant program output its version to standard output,
    not standard error. This may help some programs that use this
    output.
  + Fix a bug in the Voikko and Zemberek back-ends that could cause
    spell checking and suggestion to fail.
  + Make enchant silently ignore -B flag, for better Emacs
    compatibility.
  + Make enchant_broker_list_dicts sort the tags, so that
    enchant-lsmod’s output is sorted.
  + Minor build system improvement: don’t use -D_FORTIFY_SOURCE,
    which can cause problems on Windows, and should be configured
    by the compiler vendor if desired.
  + Fix Hunspell backend to treat apostrophes as Hunspell does: if
    either straight or curly apostrophe is a word character, allow
    both.
  + Fix a couple of space leaks in the Nuspell back end.
- Drop Fix_back-ends_that_want_a_NUL-terminated_string.patch: fixed
  upstream.
* Thu Nov  5 2020 Timo Jyrinki <tjyrinki@suse.com>
- Backport from upstream git a Voikko backend fix (bsc#1178489)
  + Add Fix_back-ends_that_want_a_NUL-terminated_string.patch
* Tue Aug 18 2020 Atri Bhattacharya <badshah400@gmail.com>
- Enable nuspell backend where it is available (openSUSE >= 1550):
  + Introduce BuildRequires: nuspell-devel and
    libboost_headers-devel.
  + Split out new package enchant-2-backend-nuspell providing the
    nuspell backend.
* Wed Aug  5 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 2.2.8:
  + Add a provider back-end for Nuspell. Nuspell is a new
    spell-checker whose development has been supported by the
    Mozilla foundation. It is backwards-compatible with Hunspell
    and Myspell dictionaries, while supporting a wider range of
    language peculiarities, improved suggestions, and easier
    maintainability of the code-base.
  + Doxygen documentation generation is now supported for Enchant.
  + The command-line parsing of the “enchant” program has been made
    more friendly and reliable. The -L flag (show line numbers),
    which had not been working for some time, has been fixed.
  + A buffer overflow in personal wordlist handling has been fixed.
  + Minor improvements were made to the tests.
- Changes in version 2.2.7:
  + Fix some memory leaks in the hunspell and aspell providers.
- Changes in version 2.2.6:
  + Treat PWL as text, not binary.
- Run spec-cleaner: Remove package groups.
* Mon Apr 13 2020 Yifan Jiang <yfjiang@suse.com>
- Enable aspell support on SLE to synchronize with Leap.
* Mon Oct 21 2019 Yifan Jiang <yfjiang@suse.com>
- Disable aspell support on SLE.
* Fri Oct 18 2019 Yifan Jiang <yfjiang@suse.com>
- Redownload the 2.2.5 tarball to reflect the consistent upstream
  release provided in Source.
* Fri Jul 19 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to version 2.2.5:
  + Fix a memory leak in the hunspell provider.
- Changes from version 2.2.4:
  + Fix a bug in the enchant program, where words ending in non-ASCII
    characters were truncated during tokenization.
* Wed Apr  3 2019 Michał Rostecki <mrostecki@opensuse.org>
- Add enchant-2-backend-aspell package which provides the aspell
  backend for enchant.
* Sun Jun  3 2018 dleuenberger@suse.com
- Revert parts of last change: Still using supplementes instead of
  boolean rich deps: zypper dup from < CODE15 is impossible
  otherwise.
* Tue May 29 2018 badshah400@gmail.com
- Fix installation of backends (bgo#1089433):
  + Drop Supplements entirely.
  + For the shared lib package, add conditional Requires on
    either/both the hunspell or voikko backends depending on
    whether the system has libhunspell and/or libvoikko installed.
  + Add a Suggests on -backend-hunspell for the case where neither
    libvoikko not libhunspell are installed.
* Sat Mar 10 2018 jengelh@inai.de
- Update descriptions.
* Wed Feb 28 2018 dimstar@opensuse.org
- Update to version 2.2.3:
  + Brown paper bag: fix 2.2.2 as intended.
- Changes from version 2.2.2:
  + Fix a bug in the build system where the test harness would try
    to delete files under root, typically the system libraries.
- Changes from version 2.2.1:
  + Fix a crash on invalid input with the hspell backend.
  + Remove some bashisms from the build system.
  + updates the Free Software Foundation’s street address.
  + Stop running some tests that fail on recent macOS.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner.
* Wed Dec 13 2017 dimstar@opensuse.org
- Update to version 2.2.0:
  + Improves support for parallel installation with other major
    versions of Enchant (specifically for man pages).
  + Fix relocation support.
  + Minor documentation improvements
  + Fix a potential crash in the hspell back-end.
- Update URL to https://abiword.github.io/enchant/.
- Adjust packaging, following the shared library packaging policy
  and allowing for coexistance of enchant-1 and enchant-2 (as
  foreseen by upstream):
  + Split enchant-1-data package (providing enchant-data, generic
    name) from libenchant1.
  + Split enchant-1-backends from libenchant1: the main backends.
  + Add conflict to libenchant1 < 1.6.1 to the split packages (and
    appropriate split provides).
  + Rename enchant-{voikko,zemberek} to
    enchant-2-backend-{voikko,zemberek}.
- Drop enchant-hunspell-1.4.0.patch: no longer needed.
* Fri Aug 11 2017 pgajdos@suse.com
- aspell to be removed from factory (bsc#1052949, FATE#323578).
* Mon May  2 2016 dimstar@opensuse.org
- Add enchant-hunspell-1.4.0.patch: Fix build against
  hunspell 1.4.0, where MAXWORDLEN is no longer exported.
* Tue Mar 26 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Sun Oct  9 2011 alinm.elena@gmail.com
- Pass --with-myspell-dir=%%{_datadir}/myspell to configure as
  myspell dictionaries are there, and not in
  %%{_datadir}/myspell/dicts (default value). Fix bnc#722693.
* Tue Oct  4 2011 vuntz@opensuse.org
- Change zemberek-server Requires in zemberek subpackage to a
  Recommends since we don't have the zemberek-server package in
  Factory; in addition, the plugin uses dbus to communicate with
  the server, and won't fail badly if the server is not there.
- Add a Supplements to zemberek subpackage for
  packageand(libenchant1:zemberek-server), to automatically install
  the zemberek plugin.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Mon Oct 11 2010 vuntz@opensuse.org
- Add enchant-voikko and enchant-zemberek to baselibs.conf.
- Add a Provides for enchant to libenchant1 in baselibs.conf, like
  in the .spec file.
* Wed Aug 25 2010 vuntz@opensuse.org
- Move the files needed by the library to the libenchant1
  subpackage, and create a tools subpackage. The enchant package is
  provided/obsoleted by libenchant1.
* Fri Jun  4 2010 coolo@novell.com
- add baselibs.conf
* Fri Apr  2 2010 vuntz@opensuse.org
- Update to version 1.6.0:
  + Add a function to get enchant's version (enchant_get_version)
  + Disable zemberek plugin by default, as it's known to cause
    issues/crashes with WebKit
  + Fix Win32 DLL dependency not found popup occurs when module has
    unmet dependencies
  + Possibly fix lp#474062
  + Fix Registry handle not closed in enchant_get_registry_value_ex
  + Fix Leak in _enchant_get_user_home_dirs() on Windows
  + Update FSF address
  + Fix Zemberek module listing a Turkish dictionary even without
    Zemberek installed
  + Don't assert if passed a null string list
  + Fix enchant_pwl_init_with_file truncating pwl file
  + Fix a double-free memory corruption bug
  + Fix some small memory leaks
  + Fix mis-acceptence of dictionaries which start with a partial
    match of the lang id
  + Fix enchant always looking in "lib" dir for plugins
  + Fix the build with the MSVC compiler
  + Add a --with-system-myspell option
  + Package missing compile-resource file
  + Compare paths ignoring case sensitivity on windows
- Drop libmalaga-devel BuildRequires.
- Pass --enable-zemberek to configure: it's in a subpackage for us,
  so we can keep it even if it's experimental.
- Explicitly list the backends in the file list to make sure we
  don't lose some of them by accident.
* Sun May 24 2009 vuntz@novell.com
- Update to version 1.5.0 (no NEWS or ChangeLog). Notable changes:
  + Look for myspell/uspell dictionaries in XDG data directories.
  + Various backends now query for any programatically-set
    dictionary paths.
  + Plug memory leaks.
  + Build fixes.
- Remove AutoReqProv: it's default now.
- Do not call autoreconf, there's no need for it.
- Use makeinstall.
* Tue Mar 17 2009 mboman@suse.de
- Don't delete "la" files for distro version <= 11.1
* Fri Mar 13 2009 crrodriguez@suse.de
- remove all "la" files
* Fri Jul 25 2008 sbrabec@suse.cz
- Build with voikko (Finnish, bnc#394355) and zemberek (Azeri,
  Turkmen, Turkish, Tatar) backends.
* Mon May 12 2008 sbrabec@suse.cz
- Updated to version 1.4.2:
  * Improved modularity, support for new modules (not yet in
    openSUSE build: Voikko, Zemberek).
  * System hunspell support improved (bnc#383308).
  * Dictionary search improvements (morphing, affixes, suffixes,
    compound words, phonetic translation table).
  * binreloc support (off in openSUSE)
* Thu Oct 18 2007 sbrabec@suse.cz
- Updated to version 1.3.0:
  * New personal wordlist implementation.
  * Bug and compilation fixes.
- Split according to shared library packaging policy.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Thu Jan  4 2007 sbrabec@suse.cz
- Spec file cleanup.
* Tue Apr 11 2006 jpr@suse.de
- Fix potential infinite loop (#164682)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 sbrabec@suse.cz
- Updated to version 1.2.0.
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Wed Aug  3 2005 sbrabec@suse.cz
- Updated to version 1.1.6.
- Removed unneeded static modules and .la files for modules.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Tue Jan 11 2005 sbrabec@suse.cz
- Updated to version 1.1.5.
* Wed May  5 2004 sbrabec@suse.cz
- Added -fno-strict-aliasing.
* Wed Oct 29 2003 sbrabec@suse.cz
- Updated to version 1.1.1.
* Thu Aug 21 2003 ro@suse.de
- fix build on x86_64
- run autoreconf for full libtool update
* Tue Aug 19 2003 sbrabec@suse.cz
- Initial SuSE version 0.2.0.
